@@ -1,2 +1,2 @@
-from .core.base_scorer import Scorer, UserScorer
+from .core.base_scorer import DeepChainApp, Scorer
 from .core.transformers_app import TransformersApp
