@@ -2,7 +2,7 @@ from abc import ABC, abstractmethod
 from typing import Any, Dict, List, Tuple
 
 
-class UserScorer(ABC):
+class DeepChainApp(ABC):
     """
     A scorer instance is used to compute the criteria value for a genotype. This class
     is a template for DeepChain App Users.
@@ -16,13 +16,13 @@ class UserScorer(ABC):
     @abstractmethod
     def score_names() -> List[str]:
         """
-        Criteria names.
+        score names.
         """
 
     @abstractmethod
     def compute_scores(self, sequences: List[str]) -> List[Dict[str, float]]:
         """
-        Score a list of genotype and for each of them return descriptors and criteria.
+        Score a list of genotype and for each of them return descriptors and score names.
         """
 
 
